package cache

import (
	"dc_golang_server_1/dbmodel"
	"dc_golang_server_1/logger"
	"fmt"
	"go.uber.org/zap"
	"log"
	"sync"
	"time"
)

// 初始化行政区域缓存
//var ProvinceMap []District // 省份列表[]District
//var CityMap sync.Map       // 城市列表map[uint32][]District  //省份ID作为KEY
//var CountyMap sync.Map     // 区县列表map[uint32][]District  //城市ID作为KEY
//type DistrictStruct struct {
//	Id      uint32 `json:"id" example:"1"`
//	Name    string `json:"name" example:"四川省"`
//	Initial string `json:"initial" example:"S"`
//}
func initBCityMaps() {
	fmt.Println(time.Now(), "cache: initBCityMaps begin")

	go func() bool {
		ProvinceMap = []DistrictStruct{} //先清空原来的缓存
		var temp DistrictStruct
		rows, err := dbmodel.PgDb.Query("SELECT id,name,initial FROM b_city WHERE level=1 ORDER BY sort")
		defer rows.Close()
		if err != nil {
			log.Panicln("ProvinceMap SELECT b_city rows", err)
		}
		for rows.Next() {
			err = rows.Scan(&temp.Id, &temp.Name, &temp.Initial)
			if err != nil {
				log.Panicln("ProvinceMap SELECT b_city rows.Scan", err)
			}
			ProvinceMap = append(ProvinceMap, temp)
		}
		// 处理完毕后，需要判断一次遍历过程中是否有错误产生
		if err = rows.Err(); err != nil {
			log.Panicln("cache: ProvinceMap rows.Err()", err)
		}
		return true
	}()
	selectToDistrictMap(2, &CityMap)
	selectToDistrictMap(3, &CountyMap)

	fmt.Println(time.Now(), "cache: initBCityMaps OK")
}

func selectToDistrictMap(level uint8, tempMap *sync.Map) bool {
	// 清空
	tempMap.Range(func(k, _ interface{}) bool {
		tempMap.Delete(k)
		return true
	})

	var parentID uint32
	var temp DistrictStruct
	rows, err := dbmodel.PgDb.Query("SELECT id,name,parent_id,initial FROM b_city WHERE level=$1 ORDER BY sort", level)
	defer rows.Close()
	if err != nil {
		log.Panicln("SELECT b_city rows", err, level)
	}
	for rows.Next() {
		err = rows.Scan(&temp.Id, &temp.Name, &parentID, &temp.Initial)
		if err != nil {
			log.Panicln("SELECT b_city rows.Scan", err, level)
		}
		var bufStruct []DistrictStruct
		if v, ok := tempMap.Load(parentID); ok { //map已经有了
			if bufStruct, ok = v.([]DistrictStruct); ok == false { //类型断言错误
				tempMap.Delete(parentID)
				logger.Log.Error("[]DistrictStruct 类型断言错误",
					zap.Uint8("level", level),
					zap.String("src", "selectToDistrictMap"))
			}
		}
		bufStruct = append(bufStruct, temp)
		tempMap.Store(parentID, bufStruct)
	}
	// 处理完毕后，需要判断一次遍历过程中是否有错误产生
	if err = rows.Err(); err != nil {
		log.Panicln("cache: selectToDistrictMap rows.Err()", err, level)
	}
	return true
}
