package web

import (
	"dc_golang_server_1/config"
	_ "dc_golang_server_1/docs"
	"dc_golang_server_1/logger"
	v1 "dc_golang_server_1/web/v1"
	"fmt"
	"github.com/gin-gonic/gin"
	"github.com/swaggo/gin-swagger"
	"github.com/swaggo/gin-swagger/swaggerFiles"
	"time"
)

func InitRouter() { //*gin.Engine{
	gin.SetMode(config.HttpServerMode)
	r := gin.New()
	r.Use(logger.HttpGinLog(), gin.Recovery())
	r.Use(Cors()) //全局跨域 局部跨域的话在路由组里面去添加
	//r.Use(CheckToken()) //jwt 还是在对应需要token的路由组添加

	fmt.Println("swagger", config.HttpServerSwagger)

	if config.HttpServerSwagger {
		r.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))
	}

	base := r.Group("base/")
	// base.Use(CheckToken())
	{
		base.GET("province", v1.GetProvinceList)
		base.GET("city/:id", v1.GetCityList)
		base.GET("county/:id", v1.GetCountyList)
		base.GET("locarea", v1.GetAreaByLocation)
		base.GET("countyarea/:id", v1.GetAreaByCounty)
	}

	r.POST("we/login/:code", v1.WeLogin)
	wechat := r.Group("we/")
	// wechat.Use(CheckToken())
	{ // 需要token的
		wechat.POST("carduser", v1.CreateCardUser)                 //创建学生
		wechat.DELETE("carduser/:id", v1.DeleteCardUser)           //删除学生
		wechat.POST("bindcarduser/:share_code", v1.BindCardUser)   //副家长绑定学生
		wechat.DELETE("bindcarduser/:id", v1.DeleteBindCardUser)   //副家长解绑学生
		wechat.GET("trend/:id", v1.GetCardUsersTrend)              //获取学生最新动态
		wechat.GET("bindcarduser/:id", v1.GetBindCardUser)         //获取学生副家长列表及邀请码内容(仅主家长有权限)
		wechat.PUT("cardusershareon/:id", v1.PutCardUserShareOn)   //打开邀请码开关(仅主家长有权限)
		wechat.PUT("cardusershareoff/:id", v1.PutCardUserShareOff) //关闭邀请码开关(仅主家长有权限)
		wechat.DELETE("slaveweuser", v1.DeleteSlaveWeUser)         //删除副家长(仅主家长有权限)
		wechat.PUT("carduser/:id", v1.PutCardUser)                 //修改学生信息
		wechat.PUT("cardloss/:id", v1.CardLoss)                    //卡挂失/解挂
		wechat.PUT("cardbind/:id", v1.CardBind)                    //绑定卡
		wechat.DELETE("cardbind/:id", v1.DeleteCardBind)           //解绑卡
		wechat.GET("phonecardstatus/:id", v1.GetPhoneCardStatus)   //获取学生公话卡状态
		//wechat.GET("callrecord/:id",v1.GetCallRecord) // 查询通话记录
		//添加亲情号
		//修改亲情号
		//删除亲情号
		//缴费
		//查询缴费记录

		//获取学生定位卡状态
		//查询通行记录
		//缴费
		//查询缴费记录
	}

	//router := r.Group("web/")
	{
		//router.POST()
	}

	fmt.Println(time.Now(), "server is running")

	err := r.Run(config.HttpServerPort)
	if err != nil {
		panic(err)
	}
}
