package v1

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"time"
)

type weLoginRes struct {
	// 自己创建的学生列表(主家长)
	Master []struct {
		// 学生ID
		ID   uint32 `json:"id"`
		Name string `json:"name"`
		// 0女 1男
		Sex uint8 `json:"sex"`
		// 区域名字
		Area string `json:"area" example:"四川省成都市温江区实验中学"`
		// "1~9对应一年级~九年级，10~12对应高一~高三"
		Grade  int8   `json:"grade"`
		Class  int8   `json:"class"`
		StuNum string `json:"stuNum"`
		// 对应6个数字对应公话、定位、饮水、卡消费、洗浴、洗衣机图标(0不显示,1正常,2显示但提示校区暂未开通该服务)
		Service []uint8 `json:"service" example:"1,2,2,0,0,0"`
		// 是否已充值(已充值则不能删除，未充值可以删除)
		TopUp bool `json:"topUp"`
	} `json:"master"`
	// 添加的学生列表(副家长)
	Slave []struct {
		// 学生ID
		ID   uint32 `json:"id"`
		Name string `json:"name"`
		// 0女 1男
		Sex uint8 `json:"sex"`
		// 区域名字
		Area string `json:"area" example:"四川省成都市温江区实验中学"`
		// "1~9对应一年级~九年级，10~12对应高一~高三"
		Grade  int8   `json:"grade"`
		Class  int8   `json:"class"`
		StuNum string `json:"stuNum"`
		// 对应6个数字对应公话、定位、饮水、卡消费、洗浴、洗衣机图标(0不显示,1正常,2显示但提示校区暂未开通该服务)
		Service []uint8 `json:"service" example:"1,2,2,0,0,0"`
	} `json:"slave"`
	// 是否已获取到微信电话
	WePhone bool `json:"wePhone"`
	// 是否已获取到微信用户信息
	WeInfo bool   `json:"weInfo"`
	Token  string `json:"token"`
}

// WeLogin 微信登录
// @Tags 家长微信
// @Summary  登录
// @Description 微信code传至后台,后台返回token,token有效时长:24小时
// @Param code path string true "用户微信的code"
// @Product json
// @Success 0 {object} weLoginRes
// @Router /we/login/{code} [POST]
func WeLogin(c *gin.Context) {
	code := c.Param("code")

	var res weLoginRes

	//todo  拿code去找腾讯要东西 生成token
	res.Token = code

	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": res,
	})
}

type weCreateCardUserReq struct {
	// 必填,学生名字,maxLen=16
	Name string `json:"name" example:"汤圆"`
	// 必填,校区ID
	AreaID uint32 `json:"areaID" example:"1"`
	// 必填，"1~9对应一年级~九年级，10~12对应高一~高三"
	Grade int8 `json:"grade"`
	// 选填,0女1男
	Sex uint8 `json:"sex,omitempty"`
	// 选填,班级,number
	Class int8 `json:"class,omitempty"`
	// 选填,学号,字符串,maxLen=32
	StudentNo string `json:"stuNum,omitempty"`
}
type creatCardUserRes struct {
	// 新创建的学生ID
	ID uint32 `json:"id"`
	// 对应6个数字对应公话、定位、饮水、卡消费、洗浴、洗衣机图标(0不显示,1正常,2显示但提示校区暂未开通该服务)
	Service [6]uint8 `json:"service" example:"1,2,2,0,0,0"`
}

// CreateCardUser 创建一个学生
// @Tags 家长微信
// @Summary  创建一个学生
// @Description 传新建学生信息至后台,后台返回学生id,以及对应校区的service
// @Accept  json
// @Produce json
// @Param data body weCreateCardUserReq true "学生信息"
// @Success 0 {object} creatCardUserRes
// @Router /we/carduser [POST]
// @Security ApiKeyAuth
func CreateCardUser(c *gin.Context) {
	res := creatCardUserRes{
		1,
		[6]uint8{1, 2, 2, 0, 0, 0},
	}
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": res,
	})
}

// DeleteCardUser 主家长删除一个学生
// @Tags 家长微信
// @Summary  主家长删除一个学生
// @Description 传学生ID至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Success 0
// @Router /we/carduser/{id} [DELETE]
// @Security ApiKeyAuth
func DeleteCardUser(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

type bindCardUserRes struct {
	// 学生ID
	ID   uint32 `json:"id"`
	Name string `json:"name"`
	// 0女 1男
	Sex uint8 `json:"sex"`
	// 区域名字
	Area string `json:"area" example:"四川省成都市温江区实验中学"`
	// "1~9对应一年级~九年级，10~12对应高一~高三"
	Grade  int8   `json:"grade"`
	Class  int8   `json:"class"`
	StuNum string `json:"stuNum"`
	// 对应6个数字对应公话、定位、饮水、卡消费、洗浴、洗衣机图标(0不显示,1正常,2显示但提示校区暂未开通该服务)
	Service []uint8 `json:"service" example:"1,2,2,0,0,0"`
}

// BindCardUser 副家长绑定学生
// @Tags 家长微信
// @Summary  副家长绑定学生
// @Description 传学生的邀请码,后台返回学生信息
// @Produce json
// @Param share_code path string true "学生的邀请码"
// @Success 0 {object} bindCardUserRes "学生信息"
// @Router /we/bindcarduser/{share_code} [POST]
// @Security ApiKeyAuth
func BindCardUser(c *gin.Context) {
	res := bindCardUserRes{}
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": res,
	})
}

// DeleteBindCardUser 副家长解绑学生
// @Tags 家长微信
// @Summary  副家长解绑学生
// @Description 传学生ID至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Success 0
// @Router /we/bindcarduser/{id} [DELETE]
// @Security ApiKeyAuth
func DeleteBindCardUser(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

type slaveWeUserRes struct {
	// 微信UnionID
	UnionID string `json:"unionID"`
	// 微信昵称
	Nickname string `json:"nickname"`
	// 头像URL
	AvatarURL string `json:"avatarURL"`
	// 绑定时间
	CreateAt time.Time `json:"createAt"`
}
type getBindCardUserRes struct {
	// 副家长微信信息列表
	WeUser []slaveWeUserRes `json:"weUser"`
	// 学生的邀请码,长度固定16,若为空,则表示邀请码开关关闭
	ShareCode string `json:"shareCode"`
}

// GetBindCardUser 获取学生副家长列表及邀请码内容(仅主家长有权限)
// @Tags 家长微信
// @Summary  获取学生副家长列表及邀请码内容(仅主家长有权限)
// @Description 传学生ID至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Success 0 {object} getBindCardUserRes "副家长信息列表及邀请码"
// @Router /we/bindcarduser/{id} [GET]
// @Security ApiKeyAuth
func GetBindCardUser(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": getBindCardUserRes{},
	})
}

// PutCardUserShareOn 打开邀请码开关(仅主家长有权限)
// @Tags 家长微信
// @Summary  打开邀请码开关(仅主家长有权限)
// @Description 传学生ID至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Success 0
// @Router /we/cardusershareon/{id} [PUT]
// @Security ApiKeyAuth
func PutCardUserShareOn(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

// PutCardUserShareOff 关闭邀请码开关(仅主家长有权限)
// @Tags 家长微信
// @Summary 关闭邀请码开关(仅主家长有权限)
// @Description 传学生ID至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Success 0
// @Router /we/cardusershareoff/{id} [PUT]
// @Security ApiKeyAuth
func PutCardUserShareOff(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

// DeleteSlaveWeUser 删除副家长(仅主家长有权限)
// @Tags 家长微信
// @Summary 删除副家长(仅主家长有权限)
// @Description 传学生ID和微信UnionID,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Param unionid query string true "副家长微信UnionID"
// @Success 0
// @Router /we/slaveweuser/{id} [DELETE]
// @Security ApiKeyAuth
func DeleteSlaveWeUser(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

type PutCardUserReq struct {
	// 必填,学生名字,maxLen=16
	Name string `json:"name" example:"汤圆"`
	// 必填，"1~9对应一年级~九年级，10~12对应高一~高三"
	Grade int8 `json:"grade"`
	// 选填,0女1男
	Sex uint8 `json:"sex,omitempty"`
	// 选填,班级,number
	Class int8 `json:"class,omitempty"`
	// 选填,学号,字符串,maxLen=32
	StudentNo string `json:"stuNum,omitempty"`
}

// PutCardUser 修改学生信息
// @Tags 家长微信
// @Summary  修改学生信息
// @Description 传学生id及新信息至后台,后台返回成功失败
// @Accept  json
// @Produce json
// @Param id path integer true "学生ID"
// @Param data body PutCardUserReq true "学生信息"
// @Success 0
// @Router /we/carduser/{id} [PUT]
// @Security ApiKeyAuth
func PutCardUser(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

// CardLoss 卡挂失/解挂
// @Tags 家长微信
// @Summary  卡挂失/解挂
// @Description 传学生id及卡类型至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Param loss query bool true "true挂失,false解挂"
// @Param type query integer true "卡类型:1电话卡,2定位卡,3IC卡(饮水、消费、洗浴、洗衣机均为IC卡,固任何一个服务的卡挂失状态改变,其余也跟随改变)"
// @Success 0
// @Router /we/cardloss/{id} [PUT]
// @Security ApiKeyAuth
func CardLoss(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

// CardBind 绑定卡
// @Tags 家长微信
// @Summary  绑定卡
// @Description 传学生id及卡类型、卡号至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Param code query string true "卡号"
// @Param type query integer true "卡类型:1电话卡,2定位卡,3IC卡(饮水、消费、洗浴、洗衣机均为IC卡,固任何一个服务的卡挂失状态改变,其余也跟随改变)"
// @Success 0
// @Router /we/cardbind/{id} [PUT]
// @Security ApiKeyAuth
func CardBind(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

// DeleteCardBind 解绑卡
// @Tags 家长微信
// @Summary  解绑卡
// @Description 传学生id及卡类型至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Param type query integer true "卡类型:1电话卡,2定位卡,3IC卡(饮水、消费、洗浴、洗衣机均为IC卡,固任何一个服务的卡挂失状态改变,其余也跟随改变)"
// @Success 0
// @Router /we/cardbind/{id} [DELETE]
// @Security ApiKeyAuth
func DeleteCardBind(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
	})
}

type getPhoneCardStatusRes struct {
	// 状态 0未绑定卡   1 正常使用   2 服务已到期 3 已挂失
	Status uint8 `json:"status"`
	// 卡号
	SimID string `json:"simID"`
	// 到期时间
	ExpiryAt time.Time `json:"expiryAt"`
	// 月套餐使用分钟数
	MonthMin uint16 `json:"monthMin"`
	// 月套餐分钟数
	MonthPack uint16 `json:"monthPack"`
	// 本月可修改亲情号次数
	Changeable uint8 `json:"changeable"`
	// 亲情号列表
	Family []struct {
		Phone string `json:"phone"`
		Name  string `json:"name"`
	} `json:"family"`
}

// GetPhoneCardStatus 获取学生公话卡状态
// @Tags 家长微信
// @Summary  获取学生公话卡状态
// @Description 传学生ID至后台,后台返回卡信息
// @Produce json
// @Param id path integer true "学生ID"
// @Success 0 {object} getPhoneCardStatusRes "公话卡状态信息"
// @Router /we/phonecardstatus/{id} [GET]
// @Security ApiKeyAuth
func GetPhoneCardStatus(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": getPhoneCardStatusRes{},
	})
}

type getCallRecordRes struct {
	// 状态 0未绑定卡   1 正常使用   2 服务已到期 3 已挂失
	Status uint8 `json:"status"`
	// 卡号
	SimID string `json:"simID"`
	// 到期时间
	ExpiryAt time.Time `json:"expiryAt"`
	// 月套餐使用分钟数
	MonthMin uint16 `json:"monthMin"`
	// 月套餐分钟数
	MonthPack uint16 `json:"monthPack"`
	// 本月可修改亲情号次数
	Changeable uint8 `json:"changeable"`
	// 亲情号列表
	Family []struct {
		Phone string `json:"phone"`
		Name  string `json:"name"`
	} `json:"family"`
}

//// GetCallRecord 查询通话记录
//// @Tags 家长微信
//// @Summary  查询通话记录
//// @Description 传学生ID至后台,后台返回通话记录列表
//// @Produce json
//// @Param id path integer true "学生ID"
//// @Param pnum query integer true "页数"
//// @Param psize query integer true "页条数"
//// @Param start quety string false "起始时间 2020-10-10 10:00:00"
//// @Param end quety string false "结束时间 2030-10-10 10:00:00"
//// @Param asc quety bool false "是否升序" default(false)
//// @Success 0 {object} []getPhoneCardStatusRes "通话记录列表"
//// @Router /we/callrecord/{id} [GET]
//// @Security ApiKeyAuth
//func GetCallRecord(c *gin.Context) {
//	c.JSON(http.StatusOK, gin.H{
//		"code": SUCCSE,
//		"data": getPhoneCardStatusRes{},
//	})
//}
